# Generated by Django 3.2.6 on 2021-08-09 08:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("app", "0003_auto_20180416_1020"),
    ]

    operations = [
        migrations.AlterField(
            model_name="continent",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="country",
            name="commonwealth",
            field=models.BooleanField(null=True),
        ),
        migrations.AlterField(
            model_name="country",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="person",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
