{% extends 'django_tables2/bootstrap5.html' %}

{% block table-wrapper %}
<div class="table-container table-responsive">
    {% block table %}
        {{ block.super }}
    {% endblock table %}

    {% block pagination %}
        {{ block.super }}
    {% endblock pagination %}
</div>
{% endblock table-wrapper %}
